:py:mod:`Heron.decorators`
==========================

.. py:module:: Heron.decorators


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   Heron.decorators.deprecated



Attributes
~~~~~~~~~~

.. autoapisummary::

   Heron.decorators.string_types


.. py:data:: string_types
   

   

.. py:function:: deprecated(reason)

   This is a decorator which can be used to mark functions
   as deprecated. It will result in a warning being emitted
   when the function is used.


